AnyTokioStream

Enum AnyTokioStream 

pub enum AnyTokioStream {
    Tcp(TcpStream),
    Unix(UnixStream),
}
A connected stream-type socket, either TCP or Unix-domain, adapted for use with tokio.

AnyTokioStreams are usually obtained from a call to AnyTokioListener::accept. This type implements AsyncRead and AsyncWrite, and is used to communicate with the connected peer in much the same way as a tokio::net::TcpStream.

Availability

All platforms, but the Unix variant is only available on Unix-like platforms. Converting a Unix-domain socket on Windows will result in an error.

Requires the tokio feature.

Variants



Tcp(TcpStream)

A connected TCP socket.

Availability

All platforms.



Unix(UnixStream)

A connected Unix-domain stream-type socket.

Availability

Unix-like platforms only. Tokio currently does not support Unix-domain sockets on Windows.

Implementations

Source

impl AnyTokioStream

pub fn local_addr(&self) -> Result<SockAddr>

Returns the local address that this socket is bound to.

This method delegates to tokio::net::TcpStream::local_addr or tokio::net::UnixStream::local_addr, as appropriate.

pub fn peer_addr(&self) -> Result<SockAddr>

Returns the remote address that this socket is connected to.

This method delegates to tokio::net::TcpStream::peer_addr or tokio::net::UnixStream::peer_addr, as appropriate.